==> opencascade-7.8.1-2.gpkg.tar: image/usr/lib64/cmake/opencascade/OpenCASCADEDrawTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKDraw" for configuration "RelWithDebInfo"
set_property(TARGET TKDraw APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKDraw PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKDraw.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKDraw.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKDraw )
list(APPEND _cmake_import_check_files_for_TKDraw "${_IMPORT_PREFIX}/lib64/opencascade/libTKDraw.so.7.8.1" )

# Import target "TKTopTest" for configuration "RelWithDebInfo"
set_property(TARGET TKTopTest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKTopTest PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKTopTest.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKTopTest.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKTopTest )
list(APPEND _cmake_import_check_files_for_TKTopTest "${_IMPORT_PREFIX}/lib64/opencascade/libTKTopTest.so.7.8.1" )

# Import target "TKOpenGlTest" for configuration "RelWithDebInfo"
set_property(TARGET TKOpenGlTest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKOpenGlTest PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGlTest.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKOpenGlTest.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKOpenGlTest )
list(APPEND _cmake_import_check_files_for_TKOpenGlTest "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGlTest.so.7.8.1" )

# Import target "TKViewerTest" for configuration "RelWithDebInfo"
set_property(TARGET TKViewerTest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKViewerTest PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKViewerTest.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKViewerTest.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKViewerTest )
list(APPEND _cmake_import_check_files_for_TKViewerTest "${_IMPORT_PREFIX}/lib64/opencascade/libTKViewerTest.so.7.8.1" )

# Import target "TKXSDRAW" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAW PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAW.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAW.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAW )
list(APPEND _cmake_import_check_files_for_TKXSDRAW "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAW.so.7.8.1" )

# Import target "TKDCAF" for configuration "RelWithDebInfo"
set_property(TARGET TKDCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKDCAF PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKDCAF.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKDCAF.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKDCAF )
list(APPEND _cmake_import_check_files_for_TKDCAF "${_IMPORT_PREFIX}/lib64/opencascade/libTKDCAF.so.7.8.1" )

# Import target "TKXDEDRAW" for configuration "RelWithDebInfo"
set_property(TARGET TKXDEDRAW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXDEDRAW PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXDEDRAW.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXDEDRAW.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXDEDRAW )
list(APPEND _cmake_import_check_files_for_TKXDEDRAW "${_IMPORT_PREFIX}/lib64/opencascade/libTKXDEDRAW.so.7.8.1" )

# Import target "TKTObjDRAW" for configuration "RelWithDebInfo"
set_property(TARGET TKTObjDRAW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKTObjDRAW PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKTObjDRAW.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKTObjDRAW.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKTObjDRAW )
list(APPEND _cmake_import_check_files_for_TKTObjDRAW "${_IMPORT_PREFIX}/lib64/opencascade/libTKTObjDRAW.so.7.8.1" )

# Import target "TKQADraw" for configuration "RelWithDebInfo"
set_property(TARGET TKQADraw APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKQADraw PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKQADraw.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKQADraw.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKQADraw )
list(APPEND _cmake_import_check_files_for_TKQADraw "${_IMPORT_PREFIX}/lib64/opencascade/libTKQADraw.so.7.8.1" )

# Import target "TKXSDRAWDE" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWDE APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWDE PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWDE.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWDE.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWDE )
list(APPEND _cmake_import_check_files_for_TKXSDRAWDE "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWDE.so.7.8.1" )

# Import target "TKXSDRAWGLTF" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWGLTF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWGLTF PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWGLTF.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWGLTF.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWGLTF )
list(APPEND _cmake_import_check_files_for_TKXSDRAWGLTF "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWGLTF.so.7.8.1" )

# Import target "TKXSDRAWIGES" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWIGES APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWIGES PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWIGES.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWIGES.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWIGES )
list(APPEND _cmake_import_check_files_for_TKXSDRAWIGES "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWIGES.so.7.8.1" )

# Import target "TKXSDRAWOBJ" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWOBJ APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWOBJ PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWOBJ.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWOBJ.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWOBJ )
list(APPEND _cmake_import_check_files_for_TKXSDRAWOBJ "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWOBJ.so.7.8.1" )

# Import target "TKXSDRAWPLY" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWPLY APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWPLY PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWPLY.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWPLY.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWPLY )
list(APPEND _cmake_import_check_files_for_TKXSDRAWPLY "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWPLY.so.7.8.1" )

# Import target "TKXSDRAWSTEP" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWSTEP APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWSTEP PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTEP.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWSTEP.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWSTEP )
list(APPEND _cmake_import_check_files_for_TKXSDRAWSTEP "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTEP.so.7.8.1" )

# Import target "TKXSDRAWSTL" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWSTL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWSTL PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTL.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWSTL.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWSTL )
list(APPEND _cmake_import_check_files_for_TKXSDRAWSTL "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTL.so.7.8.1" )

# Import target "TKXSDRAWVRML" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWVRML APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWVRML PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWVRML.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWVRML.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWVRML )
list(APPEND _cmake_import_check_files_for_TKXSDRAWVRML "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWVRML.so.7.8.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> opencascade-7.8.1-7.gpkg.tar: image/usr/lib64/cmake/opencascade/OpenCASCADEDrawTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKDraw" for configuration "RelWithDebInfo"
set_property(TARGET TKDraw APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKDraw PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKDraw.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKDraw.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKDraw )
list(APPEND _cmake_import_check_files_for_TKDraw "${_IMPORT_PREFIX}/lib64/opencascade/libTKDraw.so.7.8.1" )

# Import target "TKTopTest" for configuration "RelWithDebInfo"
set_property(TARGET TKTopTest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKTopTest PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKTopTest.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKTopTest.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKTopTest )
list(APPEND _cmake_import_check_files_for_TKTopTest "${_IMPORT_PREFIX}/lib64/opencascade/libTKTopTest.so.7.8.1" )

# Import target "TKOpenGlTest" for configuration "RelWithDebInfo"
set_property(TARGET TKOpenGlTest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKOpenGlTest PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGlTest.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKOpenGlTest.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKOpenGlTest )
list(APPEND _cmake_import_check_files_for_TKOpenGlTest "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGlTest.so.7.8.1" )

# Import target "TKViewerTest" for configuration "RelWithDebInfo"
set_property(TARGET TKViewerTest APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKViewerTest PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKViewerTest.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKViewerTest.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKViewerTest )
list(APPEND _cmake_import_check_files_for_TKViewerTest "${_IMPORT_PREFIX}/lib64/opencascade/libTKViewerTest.so.7.8.1" )

# Import target "TKXSDRAW" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAW PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAW.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAW.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAW )
list(APPEND _cmake_import_check_files_for_TKXSDRAW "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAW.so.7.8.1" )

# Import target "TKDCAF" for configuration "RelWithDebInfo"
set_property(TARGET TKDCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKDCAF PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKDCAF.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKDCAF.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKDCAF )
list(APPEND _cmake_import_check_files_for_TKDCAF "${_IMPORT_PREFIX}/lib64/opencascade/libTKDCAF.so.7.8.1" )

# Import target "TKXDEDRAW" for configuration "RelWithDebInfo"
set_property(TARGET TKXDEDRAW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXDEDRAW PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXDEDRAW.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXDEDRAW.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXDEDRAW )
list(APPEND _cmake_import_check_files_for_TKXDEDRAW "${_IMPORT_PREFIX}/lib64/opencascade/libTKXDEDRAW.so.7.8.1" )

# Import target "TKTObjDRAW" for configuration "RelWithDebInfo"
set_property(TARGET TKTObjDRAW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKTObjDRAW PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKTObjDRAW.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKTObjDRAW.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKTObjDRAW )
list(APPEND _cmake_import_check_files_for_TKTObjDRAW "${_IMPORT_PREFIX}/lib64/opencascade/libTKTObjDRAW.so.7.8.1" )

# Import target "TKQADraw" for configuration "RelWithDebInfo"
set_property(TARGET TKQADraw APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKQADraw PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKQADraw.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKQADraw.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKQADraw )
list(APPEND _cmake_import_check_files_for_TKQADraw "${_IMPORT_PREFIX}/lib64/opencascade/libTKQADraw.so.7.8.1" )

# Import target "TKIVtkDraw" for configuration "RelWithDebInfo"
set_property(TARGET TKIVtkDraw APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKIVtkDraw PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKIVtkDraw.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKIVtkDraw.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKIVtkDraw )
list(APPEND _cmake_import_check_files_for_TKIVtkDraw "${_IMPORT_PREFIX}/lib64/opencascade/libTKIVtkDraw.so.7.8.1" )

# Import target "TKXSDRAWDE" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWDE APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWDE PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWDE.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWDE.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWDE )
list(APPEND _cmake_import_check_files_for_TKXSDRAWDE "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWDE.so.7.8.1" )

# Import target "TKXSDRAWGLTF" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWGLTF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWGLTF PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWGLTF.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWGLTF.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWGLTF )
list(APPEND _cmake_import_check_files_for_TKXSDRAWGLTF "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWGLTF.so.7.8.1" )

# Import target "TKXSDRAWIGES" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWIGES APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWIGES PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWIGES.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWIGES.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWIGES )
list(APPEND _cmake_import_check_files_for_TKXSDRAWIGES "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWIGES.so.7.8.1" )

# Import target "TKXSDRAWOBJ" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWOBJ APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWOBJ PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWOBJ.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWOBJ.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWOBJ )
list(APPEND _cmake_import_check_files_for_TKXSDRAWOBJ "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWOBJ.so.7.8.1" )

# Import target "TKXSDRAWPLY" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWPLY APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWPLY PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWPLY.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWPLY.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWPLY )
list(APPEND _cmake_import_check_files_for_TKXSDRAWPLY "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWPLY.so.7.8.1" )

# Import target "TKXSDRAWSTEP" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWSTEP APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWSTEP PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTEP.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWSTEP.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWSTEP )
list(APPEND _cmake_import_check_files_for_TKXSDRAWSTEP "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTEP.so.7.8.1" )

# Import target "TKXSDRAWSTL" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWSTL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWSTL PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTL.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWSTL.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWSTL )
list(APPEND _cmake_import_check_files_for_TKXSDRAWSTL "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWSTL.so.7.8.1" )

# Import target "TKXSDRAWVRML" for configuration "RelWithDebInfo"
set_property(TARGET TKXSDRAWVRML APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKXSDRAWVRML PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWVRML.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKXSDRAWVRML.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKXSDRAWVRML )
list(APPEND _cmake_import_check_files_for_TKXSDRAWVRML "${_IMPORT_PREFIX}/lib64/opencascade/libTKXSDRAWVRML.so.7.8.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
